@@ -6,14 +6,9 @@ import logging
 import os
 import re
 
-import boto3
 import pytz
 from toolz import pipe
 from toolz.curried import filter as filterz
-from toolz.curried import last as lastz
-from toolz.curried import map as mapz
-from toolz.curried import mapcat as mapcatz
-from toolz.curried import sorted as sortedz
 
 from trailscraper.boto_service_definitions import operation_definition
 from trailscraper.iam import Statement, Action
@@ -247,63 +242,6 @@ def parse_records(json_records):
     parsed_records = [_parse_record(record) for record in json_records]
     return [r for r in parsed_records if r is not None]
 
-
-def _valid_log_files(log_dir):
-    def _valid_or_warn(log_file):
-        if log_file.has_valid_filename():
-            return True
-
-        logging.warning("Invalid filename: %s", log_file.filename())
-        return False
-
-    def _to_paths(triple):
-        root, _, files_in_dir = triple
-        return [os.path.join(root, file_in_dir) for file_in_dir in files_in_dir]
-
-    return pipe(os.walk(log_dir),
-                mapcatz(_to_paths),
-                mapz(LogFile),
-                filterz(_valid_or_warn))
-
-
-def load_from_dir(log_dir, from_date, to_date):
-    """Loads all CloudTrail Records in a file"""
-    records = []
-    for logfile in _valid_log_files(log_dir):
-        if logfile.contains_events_for_timeframe(from_date, to_date):
-            records.extend(logfile.records())
-
-    return records
-
-
-def last_event_timestamp_in_dir(log_dir):
-    """Return the timestamp of the most recent event in the given directory"""
-    most_recent_file = pipe(_valid_log_files(log_dir),
-                            sortedz(key=LogFile.timestamp),
-                            lastz,
-                            LogFile.records,
-                            sortedz(key=lambda record: record.event_time),
-                            lastz)
-
-    return most_recent_file.event_time
-
-
-def load_from_api(from_date, to_date):
-    """Loads the last 10 hours of cloudtrail events from the API"""
-    client = boto3.client('cloudtrail')
-    paginator = client.get_paginator('lookup_events')
-    response_iterator = paginator.paginate(
-        StartTime=from_date,
-        EndTime=to_date,
-    )
-    records = []
-    for response in response_iterator:
-        for event in response['Events']:
-            records.append(_parse_record(json.loads(event['CloudTrailEvent'])))
-
-    return records
-
-
 def _by_timeframe(from_date, to_date):
     return lambda record: record.event_time is None or \
                           (from_date <= record.event_time <= to_date)
